@@ -38,9 +38,9 @@
 
 #define LIBOFX_MAJOR_VERSION 0
 #define LIBOFX_MINOR_VERSION 9
-#define LIBOFX_MICRO_VERSION 11
+#define LIBOFX_MICRO_VERSION 13
 #define LIBOFX_BUILD_VERSION 0
-#define LIBOFX_VERSION_RELEASE_STRING "0.9.11"
+#define LIBOFX_VERSION_RELEASE_STRING "0.9.13"
 
 #ifdef IN_LIBOFX
 #  include "config.h"
@@ -107,7 +107,7 @@ extern "C" {
    *
    @return the new context, to be used by the other functions.
   */
-  LibofxContextPtr libofx_get_new_context();
+  LibofxContextPtr libofx_get_new_context(void);
 
   /**
    * \brief Free all ressources used by this context.
